@@ -12,6 +12,7 @@ import org.gcube.portlets.widgets.ckan2zenodopublisher.client.view.FormValidator
 import org.gcube.portlets.widgets.ckan2zenodopublisher.client.view.LoaderIcon;
 import org.gcube.portlets.widgets.ckan2zenodopublisher.shared.CatalogueItem;
 import org.gcube.portlets.widgets.ckan2zenodopublisher.shared.ZenodoError;
+import org.gcube.portlets.widgets.ckan2zenodopublisher.shared.wrapped.DOI_dv;
 import org.gcube.portlets.widgets.ckan2zenodopublisher.shared.wrapped.ZenodoItem;
 
 import com.github.gwtbootstrap.client.ui.Alert;
@@ -30,6 +31,8 @@ import com.google.gwt.json.client.JSONParser;
 import com.google.gwt.json.client.JSONValue;
 import com.google.gwt.user.client.Window;
 import com.google.gwt.user.client.rpc.AsyncCallback;
+import com.google.gwt.user.client.ui.FlowPanel;
+import com.google.gwt.user.client.ui.HTML;
 import com.google.gwt.user.client.ui.VerticalPanel;
 import com.google.gwt.user.client.ui.Widget;
 
@@ -164,7 +167,7 @@ public class CkanToZendoPublisherWidget {
 					//Submit publish on zenodo.
 					ZenodoItem zenodoItem = manager.getZenodoItemFromFieldsForm();
 					GWT.log("Publishing file:  "+zenodoItem.getFiles());
-					ckanToZenodoService.publishOnZenodo(zenodoItem, new AsyncCallback<String>() {
+					ckanToZenodoService.publishOnZenodo(zenodoItem, new AsyncCallback<DOI_dv>() {
 
 						@Override
 						public void onFailure(Throwable caught) {
@@ -180,7 +183,7 @@ public class CkanToZendoPublisherWidget {
 						}
 
 						@Override
-						public void onSuccess(String doi) {
+						public void onSuccess(DOI_dv doi_dv) {
 							buttonPublish.setEnabled(false);
 							basicTabPanel.getElement().getStyle().setOpacity(1.0);
 							try {
@@ -189,16 +192,28 @@ public class CkanToZendoPublisherWidget {
 								// TODO: handle exception
 							}
 							String msg = "The item has been uploaded to Zenodo correctly";
-							
-							if(doi!=null)
-								msg+=" "+doi;
-							
+					
 							Alert infoLabel = new Alert();
 							infoLabel.setClose(false);
 							infoLabel.setType(AlertType.INFO);
 							infoLabel.setText(msg);
 							
-							showResults(Arrays.asList(infoLabel.asWidget()));
+							Modal modal = new Modal(true, true);
+							modal.setCloseVisible(true);
+							modal.setTitle("Item uploaded to Zenodo!");
+							modal.add(infoLabel);
+							if(doi_dv!=null) {
+								FlowPanel dF = new FlowPanel();
+								dF.add(new HTML("DOI: "+doi_dv.getDoi()));
+								FlowPanel dFU = new FlowPanel();
+								dFU.add(new HTML("DOI URL: <a href='"+doi_dv.getDoi_url()+"'>"+doi_dv.getDoi_url()+"</a>"));
+								modal.add(dF);
+								modal.add(dFU);
+							}
+							
+							modal.show();
+						
+							//showResults(Arrays.asList(infoLabel.asWidget()));
 						}
 					});
 				
